@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.9.0;
+package Pcore::WebDriver v0.9.1;
 
 use Pcore -dist, -const, -class, -result,
   -export => {
@@ -183,6 +183,14 @@ sub update_all ( $self, $cb = undef ) {
     return $blocking_cv ? $blocking_cv->recv : ();
 }
 
+sub DEMOLISH ( $self, $global ) {
+
+    # term process group
+    kill '-TERM', $self->{_proc}->{pid} if $self->{_proc};    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+
+    return;
+}
+
 around new => sub ( $orig, $self, $driver, @args ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
 
@@ -263,8 +271,8 @@ sub new_session ( $self, @args ) {
 ## |    3 | 115, 154             | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
-## |      | 232                  | * Private subroutine/method '_get_chrome_cmd' declared but not used                                            |
-## |      | 240                  | * Private subroutine/method '_get_phantomjs_cmd' declared but not used                                         |
+## |      | 240                  | * Private subroutine/method '_get_chrome_cmd' declared but not used                                            |
+## |      | 248                  | * Private subroutine/method '_get_phantomjs_cmd' declared but not used                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
